==> Gambio v4.1.1.2.zip: Vollversion GX v4.1.1.2/Shopsystem/Dateien/lang/english/original_sections/admin/gm_logo.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	gm_logo.lang.inc.php 2015-08-25 gm
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'GM_LOGO_CURRENT' => 'Current File',
	'GM_LOGO_DELETE' => 'Delete File',
	'GM_LOGO_FILE_DELETED' => 'File deleted',
	'GM_LOGO_FILE_EXISTS' => 'File already exist',
	'GM_LOGO_FILE_STATUS' => 'File status changed',
	'GM_LOGO_FILETYP_WRONG' => 'File type not allowed',
	'GM_LOGO_IMAGES_DIRECTORY_DOES_NOT_EXIST' => 'Error: Catalog images directory does not exist: ',
	'GM_LOGO_IMAGES_DIRECTORY_NOT_WRITEABLE' => 'Error: Catalog images directory is not writeable: ',
	'GM_LOGO_IMAGES_LOGOS_DIRECTORY_DOES_NOT_EXIST' => 'Error: Catalog images/logos directory does not exist: ',
	'GM_LOGO_IMAGES_LOGOS_DIRECTORY_NOT_WRITEABLE' => 'Error: Catalog images/logos directory is not writeable: ',
	'GM_LOGO_UPLOAD' => 'Upload File',
	'GM_LOGO_UPLOAD_SUCCEEDED' => 'File uploaded',
	'GM_LOGO_USE' => 'Use File',
	'HEADING_SUB_TITLE' => 'Gambio',
	'HEADING_TITLE' => 'Logo Manager',
	'MENU_TITLE_GM_LOGO_CAT' => 'Category Icon',
	'MENU_TITLE_GM_LOGO_FAVICON' => 'Favicon',
	'MENU_TITLE_GM_LOGO_FAVICON_IPAD' => 'Apple Touch Icon',
	'MENU_TITLE_GM_LOGO_FLASH' => 'Flash Logo',
	'MENU_TITLE_GM_LOGO_MAIL' => 'Email Logo',
	'MENU_TITLE_GM_LOGO_OVERLAY' => 'Watermark',
	'MENU_TITLE_GM_LOGO_PDF' => 'Invoices Logo',
	'MENU_TITLE_GM_LOGO_SHOP' => 'Shop Logo',
	'TITLE_FAILED' => 'Error',
	'TITLE_SUCCESS' => 'Update'
);

==> Gambio v5.0.2.0.zip: Vollversion GX v5.0.2.0/Shopsystem/Dateien/lang/english/original_sections/admin/gm_logo.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	gm_logo.lang.inc.php 2015-08-25 gm
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'GM_LOGO_CURRENT' => 'Current File',
	'GM_LOGO_DELETE' => 'Delete File',
	'GM_LOGO_FILE_DELETED' => 'File deleted',
	'GM_LOGO_FILE_EXISTS' => 'File already exist',
	'GM_LOGO_FILE_STATUS' => 'File status changed',
	'GM_LOGO_FILETYP_WRONG' => 'File type not allowed',
	'GM_LOGO_IMAGES_DIRECTORY_DOES_NOT_EXIST' => 'Error: Catalog images directory does not exist: ',
	'GM_LOGO_IMAGES_DIRECTORY_NOT_WRITEABLE' => 'Error: Catalog images directory is not writeable: ',
	'GM_LOGO_IMAGES_LOGOS_DIRECTORY_DOES_NOT_EXIST' => 'Error: Catalog images/logos directory does not exist: ',
	'GM_LOGO_IMAGES_LOGOS_DIRECTORY_NOT_WRITEABLE' => 'Error: Catalog images/logos directory is not writeable: ',
	'GM_LOGO_UPLOAD' => 'Upload File',
	'GM_LOGO_UPLOAD_SUCCEEDED' => 'File uploaded',
	'GM_LOGO_USE' => 'Use File',
	'HEADING_SUB_TITLE' => 'Gambio',
	'HEADING_TITLE' => 'Logo Manager',
	'MENU_TITLE_GM_LOGO_CAT' => 'Category Icon',
	'MENU_TITLE_GM_LOGO_FAVICON' => 'Favicon',
	'MENU_TITLE_GM_LOGO_FAVICON_IPAD' => 'Apple Touch Icon',
	'MENU_TITLE_GM_LOGO_MAIL' => 'E-mail Logo',
	'MENU_TITLE_GM_LOGO_PDF' => 'Invoices Logo',
	'MENU_TITLE_GM_LOGO_SHOP' => 'Shop Logo',
	'TITLE_FAILED' => 'Error',
	'TITLE_SUCCESS' => 'Update'
);
